//-------------------------------------------------------------------
// Define libray limitations that we already know about.
#define __STL_NO_NEW_STYLE_HEADERS 1
#define __STL_NO_NEW_IOSTREAMS     1

//
#define __STL_NO_WCHAR_T           1

//-------------------------------------------------------------------
// disabling exceptions (remove if -Ae is defined)
#define __STL_NO_EXCEPTIONS        1

// no std::rel_ops namespace (relational operators
#define __STL_NO_RELOPS_NAMESPACE  1

//-------------------------------------------------------------------
// Decide which allocator to use.

// set default parameter to SGI-style default alloc, not allocator<T>
#define __STL_USE_SGI_ALLOCATORS   1

// set default alloc to malloc-based allocator ( malloc_alloc_template<instance_no>, alloc.h
#define __STL_USE_MALLOC           1

// set default alloc to new-based allocator ( new_alloc, alloc.h)
#define __STL_USE_NEWALLOC         1

// make HP-style defalloc.h included in alloc.h
#define __STL_USE_DEFALLOC         1

// use debug versions of allocators
#define __STL_DEBUG_ALLOC          1

//-------------------------------------------------------------------
// Use abbreviated class names internally for linker benefit (don't affect interface)
// reduces debug output
#define __STL_USE_ABBREVS          1


//------------------------------------------------------------------
// Define compiler behaviour if we already know we have a problem

//
#define __STL_NO_PARTIAL_SPECIALIZATION_SYNTAX 1

// Probably don't have a problem. However is a namesapce has not been defined
// then the compiler will complain. So additional testing is required.
#define __STL_HAS_NO_NAMESPACES    1


//-----------------------------------------
// Keywords
// Define the keywords that are supported or not here

// usually 'typename'
#define TYPENAME_KEYWORD

// definitions for bool (comment out if '-Ab' defined)
#define BOOL_IS_INT 1
#define bool int
#define true (!0)
#define false (1)


// Standard namespace (used for sometests and would normally be 'std')
#ifdef __STL_HAS_NO_NAMESPACES
#define _TEST_STD
#else
#define _TEST_STD std
#endif


// could also be defined as '<>'
// defined as below when __STL_NO_EXPLICIT_FUNCTION_TMPL_ARGS is defiined
#define _NULLARGS


//-----------------------------------------
// Define Tests we want to do
//
// The tests are by default run if the test had compiled with the current
// compiler version (version 8.0).
//
// To carry out checks for a new compiler version define all the undef's
// below.

#undef TEST_WEAK_ATTRIBUTE
#undef TEST_BAD_ALLOC
#undef TEST_FOR_STRING_HEADER
#undef TEST_FOR_BOOL
#undef TEST_FOR_BROKEN_USING_DIRECTIVE
#undef TEST_FOR_DEFAULT_CONSTRUCTOR_BUG
#undef TEST_FOR_YVALS_H
#undef TEST_FOR_LIMITED_DEFAULT_TEMPLATES
#undef TEST_FOR_EXCEPTION_H
#undef TEST_EXCEPTIONS
#undef TEST_EXPLICIT_FUNCTION_TMPL_ARGS
#undef TEST_FOR_EXPLICIT
#undef TEST_FRIEND_TEMPLATES
#undef TEST_FUNCTION_TMPL_PARTIAL_ORDER
#undef TEST_BASE_TYPEDEF_BUG
#undef TEST_FOR_LRAND48
#undef TEST_FOR_MEMBER_TEMPLATE_CLASSES
#undef TEST_MEMBER_TEMPLATE_KEYWORD
#undef TEST_MEMBER_TEMPLATES
#undef TEST_FOR_MUTABLE
#undef TEST_FOR_STDEXCEPT_HEADER
#undef TEST_FOR_NEW_STYLE_HEADERS
#undef TEST_FOR_NEW_STYLE_NEW
#undef TEST_FOR_NONTEMPL_BASE_MATCH_BUG
#undef TEST_FOR_NON_TYPE_TMPL_PARAM_BUG
#undef TEST_PARTIAL_SPEC_NEEDS_TEMPLATE_ARGS
#undef TEST_PARTIAL_SPECIALIZATION_SYNTAX
#undef TEST_NO_FUNC_TMPL_PARTIAL_ORDER
#undef TEST_CLASS_PARTIAL_SPECIALIZATION
#undef TEST_QUALIFIED_FRIENDS
#undef TEST_FOR_AUTOMATIC_TYPE_TRAITS
#undef TEST_FOR_TYPENAME
#undef TEST_FOR_NO_ARROW_OPERATOR

// This one is different......
// if defined and no problem then we enter into an infinite loop
#undef TEST_LOOP_INLINE_PROBLEMS


extern int test_weak_attribute();
extern int test_bad_alloc();
extern int test_for_string_header();
extern int test_for_bool();
extern int test_for_broken_using_directive();
extern int test_for_default_constructor_bug(int, char**);
extern int check_for_yvals_h();
extern int const_member_constructor_bug();
extern int test_limited_default_templates();
extern int test_default_type_param();
extern int test_for_exception_h();
extern int test_exception_support();
extern int test_explicit_func_tmpl_args();
extern int test_for_explicit();
extern int test_for_loop_inline_problems();
extern int test_for_friend_templates();
extern int test_function_tmpl_partial_order();
extern int test_base_typedef_bug();
extern int test_for_lrand48();
extern int test_member_template_classes();
extern int test_member_template_keyword();
extern int test_member_templates();
extern int test_for_mutable();
extern int test_for_stdexcept_header();
extern int test_for_new_iostreams();
extern int test_new_style_casts();
extern int test_new_style_headers();
extern int test_new_style_new();
extern int test_for_nontempl_base_match_bug();
extern int test_for_non_type_tmpl_param_bug();
extern int test_partial_spec_needs_template_args();
extern int test_partial_specialization_syntax();
extern int test_no_func_tmpl_partial_order();
extern int test_partial_spec_needs_template_args1();
extern int test_partial_specialization();
extern int test_member_ptr_param_bug();
extern int test_qualified_friends();
extern int test_throw_return_bug();
extern int test_for_automatic_type_traits();
extern int test_for_typename();
extern int test_wchart_is_ushort();
extern int test_no_arrow_operator();
extern int test_for_bool_keyword();
extern int check_for_wchar_t();
extern int test_default_non_type_param();
extern int test_exception_spec_works();
extern int test_base_typedef_outside_bug();
extern int test_long_double_type();
extern int test_long_long_type();
extern int test_method_specialization();
extern int test_namespace();
extern int test_private_unint();
extern int check_sizeof_int();
extern int test_static_array_bug();
extern int test_static_const_init_bug();
extern int test_static_template_data();
extern int check_basic_stl_compatability();
extern int test_base_match_bug();
extern int test_trivial_constructor_bug();
extern int test_trivial_constructor_bug1();


// Mostly correct guess, change it for Alpha (and other environments
// that has 64-bit "long")
// #  define __STL_UINT32_T unsigned long

// Disables wchar_t functinality
// #  define __STL_NO_WCHAR_T  1

// Define if wchar_t is not a unique type, and is actually a typedef to unsigned short.
// #  define __STL_WCHAR_T_IS_USHORT 1

// Uncomment if long long is available
// #  define __STL_LONG_LONG 1

// Uncomment if long double is not available
// #  define __STL_NO_LONG_DOUBLE 1

// Uncomment this if your compiler does not support "typename" keyword
// #  define __STL_NEED_TYPENAME 1

// Uncomment this if your compiler does not support "mutable" keyword
// #  define __STL_NEED_MUTABLE 1

// Uncomment this if your compiler does not support "explicit" keyword
// #  define __STL_NEED_EXPLICIT 1

// Uncomment if new-style-casts like const_cast<> are not available
// #  define __STL_NO_NEW_STYLE_CASTS 1

// Uncomment this if your compiler does not have "bool" type
// #  define  __STL_NO_BOOL 1

// Uncomment this if your compiler does not have "bool" type, but has "bool" keyword reserved
// #  define  __STL_DONT_USE_BOOL_TYPEDEF 1

// Uncomment this if your compiler does not have "bool" type, but defines "bool" in <yvals.h>
// #  define  __STL_YVALS_H 1

// Uncomment this if your compiler has limited or no default template arguments for classes
// #  define __STL_LIMITED_DEFAULT_TEMPLATES 1

// Uncomment this if your compiler support only complete (not dependent on other parameters)
// types as default parameters for class templates
// #  define __STL_DEFAULT_TYPE_PARAM 1

// Uncomment this if your compiler has problem with not-type
// default template parameters
// #  define __STL_NO_DEFAULT_NON_TYPE_PARAM 1

// Define if compiler has
// trouble with functions getting non-type-parameterized classes as parameters
// #  define __STL_NON_TYPE_TMPL_PARAM_BUG 1

// Uncomment this if your compiler lacks static data members.
// Uncomment next line if your compiler supports __attribute__((weak))
// #  define __STL_NO_STATIC_TEMPLATE_DATA 1
// #  define __STL_WEAK_ATTRIBUTE 1

// Uncomment this if your compiler does not support namespaces
// #  define __STL_HAS_NO_NAMESPACES 1

// Uncomment if "using" keyword does not work with template types
// # define __STL_BROKEN_USING_DIRECTIVE 1

// Uncomment this if your compiler does not support exceptions
// #  define __STL_HAS_NO_EXCEPTIONS 1

// Uncomment this if your compiler does not support exception specifications
// #  define __STL_NO_EXCEPTION_SPEC

// Define this if your compiler requires return statement after throw()
// # define __STL_THROW_RETURN_BUG 1

// Header <new> that comes with the compiler
// does not define bad_alloc exception
// #  define __STL_NO_BAD_ALLOC  1

// Uncomment if member template methods are not available
// #  define __STL_NO_MEMBER_TEMPLATES   1

// Uncomment if member template classes are not available
// #  define __STL_NO_MEMBER_TEMPLATE_CLASSES   1

// Uncomment if no "template" keyword should be used with member template classes
// #  define __STL_NO_MEMBER_TEMPLATE_KEYWORD   1

// Uncomment if friend member templates are not available
// #  define __STL_NO_FRIEND_TEMPLATES   1

// Compiler does not accept friend declaration qualified with namespace name.
// #  define __STL_NO_QUALIFIED_FRIENDS 1

// Uncomment if partial specialization is not available
// #  define __STL_NO_CLASS_PARTIAL_SPECIALIZATION 1

// Define if class being partially specialized require full name (template parameters)
// of itself for method declarations
// #  define __STL_PARTIAL_SPEC_NEEDS_TEMPLATE_ARGS

// partial specialization has bugs that prevent you from
// using new-style reverse_iterator
// #  define __STL_PARTIAL_SPECIALIZATION_BUG

// Compiler has problems specializing members of partially
// specialized class
// #  define __STL_MEMBER_SPECIALIZATION_BUG

// Uncomment if partial order of template functions is not available
// #  define __STL_NO_FUNC_PARTIAL_ORDERING 1

// Uncomment if specialization of methods is not allowed
// #  define __STL_NO_METHOD_SPECIALIZATION  1

// Uncomment if full  specialization does not use partial spec. syntax : template <> struct ....
// #  define __STL_NO_PARTIAL_SPECIALIZATION_SYNTAX  1

// Uncomment if compiler does not support explicit template arguments for functions
// # define __STL_NO_EXPLICIT_FUNCTION_TMPL_ARGS

// Uncomment if "__typetraits is being instaniated automatically by the compiler (SGI only ?)
// #  define __STL_AUTOMATIC_TYPE_TRAITS 1

// Uncomment this if your compiler can't inline while(), for()
// #  define __STL_LOOP_INLINE_PROBLEMS 1

// Define if the compiler fails to match a template function argument of base
// #  define __STL_BASE_MATCH_BUG          1

// Define if the compiler fails to match a template function argument of base
// (non-template)
//#  define  __STL_NONTEMPL_BASE_MATCH_BUG 1

// Define if the compiler rejects outline method definition
// explicitly taking nested types/typedefs
// #  define __STL_NESTED_TYPE_PARAM_BUG   1

// Compiler requires typename keyword on outline method definition
// explicitly taking nested types/typedefs
// #define  __STL_TYPENAME_ON_RETURN_TYPE

// Define if the baseclass typedefs not visible from outside
// #  define __STL_BASE_TYPEDEF_OUTSIDE_BUG 1

// if your compiler have serious problems with typedefs, try this one
// #  define __STL_BASE_TYPEDEF_BUG          1

// Uncomment if getting errors compiling mem_fun* adaptors
// #  define __STL_MEMBER_POINTER_PARAM_BUG 1

// #  define __STL_UNINITIALIZABLE_PRIVATE  1

// Defined if the compiler
// has trouble instantiating static array members with dimension defined as enum
// # define __STL_STATIC_ARRAY_BUG

// * __STL_STATIC_CONST_INIT_BUG: defined if the compiler can't handle a
//   constant-initializer in the declaration of a static const data member
//   of integer type.  (See section 9.4.2, paragraph 4, of the C++ standard.)
// # define __STL_STATIC_CONST_INIT_BUG

// Define if default constructor for builtin integer type fails to initialize it to 0
// #  define __STL_DEFAULT_CONSTRUCTOR_BUG    1

// Defined if constructor
// required to explicitly call member's default constructors for const objects
// #  define __STL_CONST_CONSTRUCTOR_BUG    1

// Defined if the compiler has trouble calling POD-types constructors/destructors
// #  define __STL_TRIVIAL_CONSTRUCTOR_BUG    1
// #  define __STL_TRIVIAL_DESTRUCTOR_BUG    1

// Define if having problems specializing maps/sets with
// key type being const
// #  define __STL_MULTI_CONST_TEMPLATE_ARG_BUG

// Uncomment this to disable -> operators on all iterators
// #  define   __SGI_STL_NO_ARROW_OPERATOR 1

// Uncomment this to disble at() member functions for containers
// #  define   __STL_NO_AT_MEMBER_FUNCTION 1

// Uncomment if native new-style iostreams are not available
// #define    __STL_HAS_NO_NEW_IOSTREAMS	1

// Define this if compiler lacks <exception> header
// #  define __STL_NO_EXCEPTION_HEADER 1

// Uncomment this if your C library has lrand48() function
// #  define __STL_RAND48 1

// Uncomment if native new-style C library headers lile <cstddef>, etc are not available.
// #   define __STL_HAS_NO_NEW_C_HEADERS 1

// uncomment if new-style headers <new> is available
// #  define __STL_HAS_NEW_NEW_HEADER 1

// uncomment this if <iostream> and other STD headers put their stuff in ::namespace,
// not std::
// #  define __STL_VENDOR_GLOBAL_STD

// uncomment this if <cstdio> and the like put stuff in ::namespace,
// not std::
// #  define __STL_VENDOR_GLOBAL_CSTD

// Defined here so we can find compiler supplied headers
#define __STL_NATIVE_HEADER(header)    <../../include/##header>
#define __STL_NATIVE_C_HEADER(header)    <../../include/##header>
#define __STL_NATIVE_CPP_C_HEADER(header)    <../../include/##header>
#define __STL_NATIVE_OLD_STREAMS_HEADER(header) <../../include/##header>


#define __STL_DONT_THROW_RANGE_ERRORS 1


/* __STL_NO_SGI_IOSTREAMS:
 *
 *  This is major configuration switch.
 *  Turn it on to disable use of SGI iostreams and use wrappers
 *  around your compiler's iostreams, like before.
 *  Keep it off if you want to use  SGI iostreams
 *  (Note that in this case you have to compile library in ../src
 *  and supply resulting library at link time).
 *
 */

// # define   __STL_NO_SGI_IOSTREAMS	1


/*
 * This macro only works in non-SGI iostreams mode.
 *
 * Uncomment to suppress using new-style streams even if they are
 * available.
 * Beware - __STL_USE_OWN_NAMESPACE depends on this macro, too.
 * Do that only if you are absolutely sure backwards-compatible
 * <iostream.h> is not actually a wrapper with <iostream>
 * Hint : In VC++ 6.x, they are not.
 */

// #define   __STL_NO_NEW_IOSTREAMS	1

/*
 * Use this switch for embedded systems where no iostreams are available
 * at all. SGI iostreams will get disabled automatically then.
 */
// # define __STL_NO_IOSTREAMS 1

/*
 * Set __STL_DEBUG to turn the "Debug Mode" on.
 * That gets you checked iterators/ranges in the manner
 * of "Safe STL". Very useful for debugging. Thread-safe.
 * Please do not forget to link proper STLport library flavor
 * (e.g libstlport_gcc_stldebug.a) when you set this flag in SGI iostreams mode.
 */
// #define   __STL_DEBUG 1

/*
 * By default, STLport uses proxy technique to enable operator -> for
 * iterators even for those compilers that check the return type of
 * unused instantiations. If this causes problems for you, turn the following
 * switch on to disable proxy ->() operators. This actually should be done
 * in compiler-dependant section, not here.
 * auto_ptr implements proxy operator even if they are disabled in general,
 * as it is very unlikely that you instantiate auto_ptr<> on pointers and other builtins.
 * However, if this is the case, uncomment second line.
 */

// # define __STL_NO_PROXY_ARROW_OPERATOR 1
// # define __STL_NO_AUTO_PTR_PROXY_ARROW_OPERATOR 1


/*
 * If __STL_USE_OWN_NAMESPACE is in effect, STLport will try to rename std:: for the user
 * to _STL::. If you don't want this feature, or if it does not quite work for your
 * compiler, please define the following switch :
 */
// # define __STL_DONT_REDEFINE_STD 1

/*
 * Edit relative path below (or put full path) to get native
 * compiler vendor's headers included. Default is "../include"
 * Note : this cannot be set the same for different compilers, so
 * it may make sense to override in local stl_user_config.h only.
 * Hint : never install STLport in the directory that ends with "include"
 */
// #  undef __STL_NATIVE_INCLUDE_PATH
// #  define __STL_NATIVE_INCLUDE_PATH ../include
// same for C library headers like <cstring>
// #  undef __STL_NATIVE_CPP_C_INCLUDE_PATH
// #  define __STL_NATIVE_CPP_C_INCLUDE_PATH ../include
// same for C headers like <string.h>
// #  undef __STL_NATIVE_C_INCLUDE_PATH
// #  define __STL_NATIVE_C_INCLUDE_PATH ../include


/*
 * __STL_NO_RELOPS_NAMESPACE: if defined, don't put the relational
 * operator templates (>, <=. >=, !=) in namespace std::rel_ops, even
 * if the compiler supports namespaces.
 * Note : if the compiler do not support namespaces, those operators
 * will not be provided by default in future, to simulate hiding them into rel_ops.
 * For now, to get them not defined, define __STL_USE_SEPARATE_RELOPS_NAMESPACE.
 */

// #define __STL_NO_RELOPS_NAMESPACE 1

/*
 * Use this option to catch uninitialized members in your classes.
 * When it is set, construct() and destroy() fill the class storage
 * with __STL_SHRED_BYTE (see below).
 * Note : __STL_DEBUG and __STL_DEBUG_ALLOC don't set this option automatically.
 */

// # define __STL_DEBUG_UNINITIALIZED 1

/*
 * Uncomment and provide a definition for the byte with which raw memory
 * will be filled if __STL_DEBUG_ALLOC or __STL_DEBUG_UNINITIALIZED is defined.
 * Choose a value which is likely to cause a noticeable problem if dereferenced
 * or otherwise abused. A good value may already be defined for your platform; see
 * stl_config.h
 */
// #define __STL_SHRED_BYTE 0xA3

//==========================================================
// Compatibility section
//==========================================================

/*
 *  Define this macro to disable anachronistic constructs (like the ones used in HP STL and
 *  not included in final standard
 */
// define __STL_NO_ANACHRONISMS 1

/*
 *  Define this macro to disable SGI/STLport extensions (for example, to make sure your code will
 *  compile with some other implementation )
 */
// define __STL_NO_EXTENSIONS   1

/*
 * Use obsolete overloaded template functions iterator_category(), value_type(), distance_type()
 * for querying iterator properties. Please note those names are non-standard and are not guaranteed
 * to be used by every implementation. However, this setting is on by default when partial specialization
 * is not implemented in the compiler (if __STL_NO_ANACHRONISMS is not set).
 * Use of those interfaces for user-defined iterators is strongly discouraged:
 * please use public inheritance from iterator<> template to achieve desired effect.
 * Second form is to disable old-style queries in any case.
 */
// # define __STL_USE_OLD_HP_ITERATOR_QUERIES
// # define __STL_NO_OLD_HP_ITERATOR_QUERIES

/*
 * You should define this macro if compiling with MFC - STLport <stl/_config.h>
 * then include <afx.h> instead of <windows.h> to get synchronisation primitives
 *
 */

// # define __STL_USE_MFC 1

/*
 * Use minimum set of default arguments on template classes that have more
 * than one - for example map<>, set<>.
 * This has effect only if __STL_LIMITED_DEFAULT_TEMPLATES is on.
 * If __STL_MINIMUM_DEFAULT_TEMPLATE_PARAMS is set, you'll be able to compile
 * set<T> with those compilers, but you'll have to use __set__<T, less<T>>
 *
 * Affects : map<>, multimap<>, set<>, multiset<>, hash_*<>,
 * queue<>, priority_queue<>, stack<>, istream_iterator<>
 */

// # define __STL_MINIMUM_DEFAULT_TEMPLATE_PARAMS 1


/*
 * __STL_USE_SGI_STRING : Forces use of SGI string even if
 * native <string> is available. Unless you defined __STL_USE_OWN_NAMESPACE,
 * STLport uses native <string> if new iostreams are being used,
 * as part of compiled runtime library depends on it.
 * You may force use of SGI string uncommenting this macro.
 * IMPORTANT:
 * DO NOT use SGI <string> with native <iostream> unless you recompile
 * standard C++ runtime library with STLport installed, or
 * (better) defined __STL_USE_OWN_NAMESPACE
 */

// #define  __STL_USE_SGI_STRING  1

/*
 * __STL_WHOLE_NATIVE_STD : only meaningful in __STL_USE_OWN_NAMESPACE mode.
 * Normally, STLport only imports necessary components from native std:: namespace -
 * those not yet provided by STLport (<iostream>, <complex>, etc.)
 * and their dependencies (<string>, <stdexcept>).
 * You might want everything from std:: being available in std:: namespace when you
 * include corresponding STLport header (like STLport <map> provides std::map as well, etc.),
 * if you are going to use both stlport:: and std:: components in your code.
 * Otherwise this option is not recommended as it increases the size of your object files
 * and slows down compilation.
 */
// # define __STL_WHOLE_NATIVE_STD
